Blazar Style Commandments
=========================

- Step 1: Read the OpenStack Style Commandments
  https://docs.openstack.org/hacking/latest/
- Step 2: Read on

Blazar Specific Commandments
----------------------------

- [B301] Validate that logs are not translated.
- [B302] Use LOG.warning() rather than LOG.warn().
- [H904] Delay string interpolations at logging calls.
